==> mrpt_0.9.4.orig.tar.gz: mrpt-0.9.4/libs/base/src/utils/mrpt_font_9x15B.h <==
/* +---------------------------------------------------------------------------+
   |          The Mobile Robot Programming Toolkit (MRPT) C++ library          |
   |                                                                           |
   |                   http://mrpt.sourceforge.net/                            |
   |                                                                           |
   |   Copyright (C) 2005-2011  University of Malaga                           |
   |                                                                           |
   |    This software was written by the Machine Perception and Intelligent    |
   |      Robotics Lab, University of Malaga (Spain).                          |
   |    Contact: Jose-Luis Blanco  <jlblanco@ctima.uma.es>                     |
   |                                                                           |
   |  This file is part of the MRPT project.                                   |
   |                                                                           |
   |     MRPT is free software: you can redistribute it and/or modify          |
   |     it under the terms of the GNU General Public License as published by  |
   |     the Free Software Foundation, either version 3 of the License, or     |
   |     (at your option) any later version.                                   |
   |                                                                           |
   |   MRPT is distributed in the hope that it will be useful,                 |
   |     but WITHOUT ANY WARRANTY; without even the implied warranty of        |
   |     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         |
   |     GNU General Public License for more details.                          |
   |                                                                           |
   |     You should have received a copy of the GNU General Public License     |
   |     along with MRPT.  If not, see <http://www.gnu.org/licenses/>.         |
   |                                                                           |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_9x15B [] = {
31,139,8,0,0,0,0,0,4,3,237,153,79,139,100,87,
21,192,71,74,74,132,160,113,19,70,210,116,54,126,0,255,
128,52,76,211,35,198,229,124,136,135,13,149,205,40,129,64,
104,176,232,4,131,249,6,130,32,232,202,143,224,78,195,35,
13,149,133,141,10,130,140,164,25,23,13,237,78,7,178,9,
56,246,248,251,165,239,105,206,220,186,175,94,189,81,113,83,
7,126,115,206,61,247,156,123,238,191,87,239,205,204,23,239,
220,185,243,101,80,158,221,168,59,31,163,69,57,43,212,118,
142,177,111,39,187,29,216,237,192,110,7,118,59,176,219,129,
221,14,252,127,119,224,46,229,55,225,236,236,111,201,67,156,
65,171,127,204,23,185,215,105,156,108,15,229,191,76,199,18,
254,12,175,192,126,105,63,65,255,17,244,219,111,92,45,31,
226,120,163,240,77,116,172,253,1,246,85,225,117,116,75,246,
112,126,187,96,205,151,224,23,240,9,28,195,91,240,24,90,
18,117,66,183,98,90,190,14,231,215,33,242,172,153,9,191,
49,29,100,49,206,126,251,162,191,195,14,194,111,140,177,155,
228,33,157,7,112,93,180,237,109,36,230,167,246,155,49,183,
183,201,111,197,56,15,201,243,111,197,133,47,190,85,163,253,
162,218,185,31,130,186,150,30,71,87,112,94,198,136,251,58,
47,204,208,45,137,113,23,116,158,85,232,27,170,233,88,230,
122,47,189,143,81,179,214,167,244,181,196,113,163,102,143,221,
65,204,61,230,61,180,119,71,196,30,67,15,29,28,20,221,
163,197,62,99,90,210,225,124,19,78,192,123,228,28,140,183,
86,151,192,92,147,119,240,204,10,247,208,62,203,125,225,12,
237,88,174,171,37,177,222,215,233,116,140,200,55,111,44,215,
185,245,133,14,157,239,94,222,111,186,214,36,234,230,26,206,
115,155,186,57,215,248,43,184,128,30,252,45,115,28,99,198,
196,57,26,167,14,105,249,162,47,235,86,220,1,1,146,247,
33,114,186,226,55,47,238,209,188,216,250,204,233,96,27,201,
247,47,219,173,220,86,141,142,64,235,229,185,180,114,151,56,
87,133,30,221,65,228,97,222,62,91,218,181,184,175,158,131,
231,227,187,32,254,190,235,251,96,6,142,235,248,45,113,94,
57,223,49,196,181,134,173,110,201,125,156,199,96,191,58,183,
179,143,174,53,137,245,190,71,207,172,66,223,166,57,215,117,
172,149,57,166,109,76,75,174,113,206,19,254,54,229,182,182,
49,45,121,134,115,150,176,70,110,135,221,202,141,245,70,140,
250,18,206,10,155,214,27,49,161,157,71,216,89,227,94,19,
215,231,25,111,194,152,150,156,224,236,6,248,62,126,191,69,
246,160,37,206,235,24,190,5,175,130,255,110,35,218,250,236,
51,166,37,245,121,180,218,67,103,228,152,127,3,247,40,158,
3,181,254,12,205,53,177,255,35,248,67,33,242,125,166,46,
11,198,180,164,245,12,229,122,11,146,140,105,201,59,56,115,
172,237,89,131,86,238,80,93,231,238,188,173,251,155,86,34,
190,86,221,215,240,231,243,25,90,175,119,198,190,152,167,237,
62,97,223,208,189,122,70,223,166,251,24,125,132,173,137,227,
110,98,211,62,231,60,227,2,247,80,166,212,141,187,161,118,
61,222,57,199,111,73,212,141,185,69,157,250,236,166,228,198,
24,161,91,185,62,35,125,161,67,199,251,36,191,19,141,169,
101,137,195,152,109,48,182,150,25,142,121,193,49,98,142,241,
222,237,240,245,80,139,99,117,91,210,170,107,157,67,112,159,
191,11,255,11,241,172,179,196,250,92,219,127,42,174,105,5,
61,120,46,222,155,75,120,12,45,113,159,131,123,216,126,139,
154,19,216,214,63,38,81,55,198,82,59,143,214,30,59,86,
159,184,192,190,130,168,169,182,173,127,76,14,9,88,128,57,
238,235,88,221,19,98,206,11,113,55,239,211,14,59,52,174,
141,242,1,189,151,112,92,56,66,91,251,20,206,10,218,33,
246,5,173,125,142,156,136,207,58,238,190,190,61,136,118,214,
185,86,206,237,105,136,242,4,250,6,43,124,193,18,59,100,
142,17,44,176,125,87,239,23,180,245,173,160,37,67,243,220,
102,206,121,188,31,208,240,247,177,69,142,107,217,83,247,57,
143,145,239,85,156,141,235,213,63,38,173,186,241,28,197,29,
80,183,228,2,231,21,68,77,181,109,253,125,2,115,77,126,
132,231,247,48,111,176,22,92,57,226,222,58,47,237,30,172,
61,116,175,232,186,125,102,90,207,143,207,216,137,65,35,146,
215,25,118,172,119,36,245,118,143,22,4,138,103,35,222,177,
49,137,90,249,94,249,251,225,56,99,98,110,212,179,150,53,
109,235,31,147,168,155,245,21,73,113,190,199,216,71,3,131,
120,22,29,212,239,224,214,25,189,73,92,126,214,180,227,183,
173,246,27,91,75,29,51,212,174,243,246,112,56,191,76,71,
91,178,79,219,216,90,188,191,158,201,91,117,199,174,189,219,
129,221,14,236,118,96,183,3,187,29,216,237,192,110,7,210,
14,248,45,161,212,223,23,117,251,38,170,253,231,119,112,47,
193,111,177,87,10,126,139,232,251,60,12,201,9,29,126,235,
198,183,149,223,110,97,191,134,253,47,248,2,180,100,133,243,
26,30,194,247,138,182,173,127,147,196,183,227,130,160,67,240,
251,207,239,179,208,241,173,134,107,77,234,61,137,189,51,176,
238,171,147,173,101,205,57,132,109,59,230,209,37,27,243,86,
34,230,214,49,193,136,245,185,230,223,194,175,224,39,69,219,
214,239,186,141,107,201,62,78,215,117,4,254,95,185,90,9,
125,211,26,254,243,17,93,158,143,127,223,125,181,160,173,207,
190,109,228,154,32,233,19,152,147,228,116,139,232,214,94,185,
71,63,133,95,195,166,189,114,252,109,106,16,214,148,19,188,
231,5,237,41,114,151,224,192,191,131,73,180,213,225,195,124,
78,246,104,121,166,158,175,113,47,193,28,142,96,76,234,92,
199,112,44,253,99,146,235,141,197,142,245,175,8,168,249,59,
190,15,192,181,4,152,159,201,83,254,188,134,199,137,11,236,
71,21,52,71,229,101,34,14,64,253,223,146,142,129,124,54,
28,87,241,76,190,84,180,118,176,143,189,141,120,30,62,111,
18,103,115,180,77,98,137,241,153,205,207,171,251,228,252,244,
217,215,18,247,220,223,236,216,251,247,177,87,240,15,120,2,
142,241,41,244,80,139,57,57,247,109,218,190,71,252,255,160,
14,226,238,152,95,139,251,244,85,184,11,238,211,207,224,47,
224,125,24,171,75,200,237,239,119,216,49,142,115,114,254,178,
180,51,137,125,214,50,86,57,132,5,248,91,33,62,123,97,
171,179,116,52,98,61,250,167,228,90,47,226,167,230,62,32,
225,20,124,94,149,24,39,230,185,105,206,198,187,62,81,166,
228,58,231,175,21,242,252,183,173,107,189,79,193,154,222,63,
241,255,201,156,175,58,248,4,187,37,75,156,43,120,15,102,
21,250,236,51,198,51,113,236,61,136,179,213,167,92,195,188,
224,30,134,173,182,47,75,71,35,159,239,148,92,243,78,224,
28,148,41,185,198,155,247,34,185,174,35,214,236,56,174,209,
179,106,97,95,150,88,171,249,202,148,92,199,247,92,23,38,
34,83,114,141,55,239,69,115,205,183,222,10,222,255,220,13,
191,68,75,180,237,171,215,251,160,248,226,57,242,30,127,4,
254,86,253,21,254,9,222,197,75,176,47,203,156,70,222,231,
88,187,113,25,215,100,95,150,142,70,236,181,254,41,185,245,
62,79,201,173,215,59,37,215,121,186,22,81,166,230,222,100,
221,252,249,99,212,10,30,194,65,65,91,159,125,181,188,139,
227,41,88,219,179,248,83,225,119,104,241,204,236,187,15,28,
249,173,204,177,242,25,229,115,201,182,185,174,39,75,71,35,
159,81,142,207,118,43,183,62,163,28,159,237,86,174,115,208,
47,74,142,207,118,43,183,35,190,158,115,196,57,167,26,92,
107,178,143,199,61,91,194,121,194,182,126,49,166,37,39,56,
205,89,129,117,253,13,86,219,14,222,198,174,101,142,195,113,
157,159,98,173,15,161,135,107,112,221,151,240,24,106,137,245,
154,175,76,201,181,222,33,44,76,68,166,228,62,32,254,20,
226,183,99,74,174,181,172,249,34,117,157,115,126,7,79,173,
107,237,144,31,98,248,125,245,8,92,139,223,131,63,135,214,
25,225,126,78,172,187,130,89,194,182,126,207,36,222,191,152,
159,189,99,243,249,30,226,115,237,158,171,239,126,199,136,92,
204,231,164,62,223,41,185,245,249,78,201,117,18,206,81,148,
41,185,115,226,243,122,247,104,59,151,26,247,188,150,122,189,
83,114,235,245,78,201,117,30,121,189,219,230,126,133,60,239,
141,223,238,162,253,13,88,194,21,120,198,226,216,135,80,75,
253,28,221,35,224,13,136,188,172,235,220,122,159,29,223,58,
57,103,168,110,189,207,83,114,235,125,158,146,91,175,119,74,
174,235,119,61,162,76,205,141,251,119,147,189,254,239,10,117,
127,196,101,253,46,141,167,224,28,252,54,250,24,252,94,178,
93,191,127,113,173,61,251,249,108,194,190,34,238,194,224,74,
234,51,138,248,172,135,114,235,51,202,57,97,15,229,58,13,
215,35,74,196,103,61,148,59,101,206,61,99,31,195,17,100,
241,57,242,247,67,150,112,94,161,47,250,141,13,217,118,206,
61,9,117,221,127,3,163,76,38,46,24,60,0,0,};

==> mrpt_1.0.0.orig.tar.gz: mrpt-1.0.0/libs/base/src/utils/mrpt_font_9x15B.h <==
/* +---------------------------------------------------------------------------+
   |                 The Mobile Robot Programming Toolkit (MRPT)               |
   |                                                                           |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2013, Individual contributors, see AUTHORS file        |
   | Copyright (c) 2005-2013, MAPIR group, University of Malaga                |
   | Copyright (c) 2012-2013, University of Almeria                            |
   | All rights reserved.                                                      |
   |                                                                           |
   | Redistribution and use in source and binary forms, with or without        |
   | modification, are permitted provided that the following conditions are    |
   | met:                                                                      |
   |    * Redistributions of source code must retain the above copyright       |
   |      notice, this list of conditions and the following disclaimer.        |
   |    * Redistributions in binary form must reproduce the above copyright    |
   |      notice, this list of conditions and the following disclaimer in the  |
   |      documentation and/or other materials provided with the distribution. |
   |    * Neither the name of the copyright holders nor the                    |
   |      names of its contributors may be used to endorse or promote products |
   |      derived from this software without specific prior written permission.|
   |                                                                           |
   | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       |
   | 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED |
   | TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR|
   | PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE |
   | FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL|
   | DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR|
   |  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)       |
   | HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,       |
   | STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN  |
   | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE           |
   | POSSIBILITY OF SUCH DAMAGE.                                               |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_9x15B [] = {
31,139,8,0,0,0,0,0,4,3,237,153,79,139,100,87,
21,192,71,74,74,132,160,113,19,70,210,116,54,126,0,255,
128,52,76,211,35,198,229,124,136,135,13,149,205,40,129,64,
104,176,232,4,131,249,6,130,32,232,202,143,224,78,195,35,
13,149,133,141,10,130,140,164,25,23,13,237,78,7,178,9,
56,246,248,251,165,239,105,206,220,186,175,94,189,81,113,83,
7,126,115,206,61,247,156,123,238,191,87,239,205,204,23,239,
220,185,243,101,80,158,221,168,59,31,163,69,57,43,212,118,
142,177,111,39,187,29,216,237,192,110,7,118,59,176,219,129,
221,14,252,127,119,224,46,229,55,225,236,236,111,201,67,156,
65,171,127,204,23,185,215,105,156,108,15,229,191,76,199,18,
254,12,175,192,126,105,63,65,255,17,244,219,111,92,45,31,
226,120,163,240,77,116,172,253,1,246,85,225,117,116,75,246,
112,126,187,96,205,151,224,23,240,9,28,195,91,240,24,90,
18,117,66,183,98,90,190,14,231,215,33,242,172,153,9,191,
49,29,100,49,206,126,251,162,191,195,14,194,111,140,177,155,
228,33,157,7,112,93,180,237,109,36,230,167,246,155,49,183,
183,201,111,197,56,15,201,243,111,197,133,47,190,85,163,253,
162,218,185,31,130,186,150,30,71,87,112,94,198,136,251,58,
47,204,208,45,137,113,23,116,158,85,232,27,170,233,88,230,
122,47,189,143,81,179,214,167,244,181,196,113,163,102,143,221,
65,204,61,230,61,180,119,71,196,30,67,15,29,28,20,221,
163,197,62,99,90,210,225,124,19,78,192,123,228,28,140,183,
86,151,192,92,147,119,240,204,10,247,208,62,203,125,225,12,
237,88,174,171,37,177,222,215,233,116,140,200,55,111,44,215,
185,245,133,14,157,239,94,222,111,186,214,36,234,230,26,206,
115,155,186,57,215,248,43,184,128,30,252,45,115,28,99,198,
196,57,26,167,14,105,249,162,47,235,86,220,1,1,146,247,
33,114,186,226,55,47,238,209,188,216,250,204,233,96,27,201,
247,47,219,173,220,86,141,142,64,235,229,185,180,114,151,56,
87,133,30,221,65,228,97,222,62,91,218,181,184,175,158,131,
231,227,187,32,254,190,235,251,96,6,142,235,248,45,113,94,
57,223,49,196,181,134,173,110,201,125,156,199,96,191,58,183,
179,143,174,53,137,245,190,71,207,172,66,223,166,57,215,117,
172,149,57,166,109,76,75,174,113,206,19,254,54,229,182,182,
49,45,121,134,115,150,176,70,110,135,221,202,141,245,70,140,
250,18,206,10,155,214,27,49,161,157,71,216,89,227,94,19,
215,231,25,111,194,152,150,156,224,236,6,248,62,126,191,69,
246,160,37,206,235,24,190,5,175,130,255,110,35,218,250,236,
51,166,37,245,121,180,218,67,103,228,152,127,3,247,40,158,
3,181,254,12,205,53,177,255,35,248,67,33,242,125,166,46,
11,198,180,164,245,12,229,122,11,146,140,105,201,59,56,115,
172,237,89,131,86,238,80,93,231,238,188,173,251,155,86,34,
190,86,221,215,240,231,243,25,90,175,119,198,190,152,167,237,
62,97,223,208,189,122,70,223,166,251,24,125,132,173,137,227,
110,98,211,62,231,60,227,2,247,80,166,212,141,187,161,118,
61,222,57,199,111,73,212,141,185,69,157,250,236,166,228,198,
24,161,91,185,62,35,125,161,67,199,251,36,191,19,141,169,
101,137,195,152,109,48,182,150,25,142,121,193,49,98,142,241,
222,237,240,245,80,139,99,117,91,210,170,107,157,67,112,159,
191,11,255,11,241,172,179,196,250,92,219,127,42,174,105,5,
61,120,46,222,155,75,120,12,45,113,159,131,123,216,126,139,
154,19,216,214,63,38,81,55,198,82,59,143,214,30,59,86,
159,184,192,190,130,168,169,182,173,127,76,14,9,88,128,57,
238,235,88,221,19,98,206,11,113,55,239,211,14,59,52,174,
141,242,1,189,151,112,92,56,66,91,251,20,206,10,218,33,
246,5,173,125,142,156,136,207,58,238,190,190,61,136,118,214,
185,86,206,237,105,136,242,4,250,6,43,124,193,18,59,100,
142,17,44,176,125,87,239,23,180,245,173,160,37,67,243,220,
102,206,121,188,31,208,240,247,177,69,142,107,217,83,247,57,
143,145,239,85,156,141,235,213,63,38,173,186,241,28,197,29,
80,183,228,2,231,21,68,77,181,109,253,125,2,115,77,126,
132,231,247,48,111,176,22,92,57,226,222,58,47,237,30,172,
61,116,175,232,186,125,102,90,207,143,207,216,137,65,35,146,
215,25,118,172,119,36,245,118,143,22,4,138,103,35,222,177,
49,137,90,249,94,249,251,225,56,99,98,110,212,179,150,53,
109,235,31,147,168,155,245,21,73,113,190,199,216,71,3,131,
120,22,29,212,239,224,214,25,189,73,92,126,214,180,227,183,
173,246,27,91,75,29,51,212,174,243,246,112,56,191,76,71,
91,178,79,219,216,90,188,191,158,201,91,117,199,174,189,219,
129,221,14,236,118,96,183,3,187,29,216,237,192,110,7,210,
14,248,45,161,212,223,23,117,251,38,170,253,231,119,112,47,
193,111,177,87,10,126,139,232,251,60,12,201,9,29,126,235,
198,183,149,223,110,97,191,134,253,47,248,2,180,100,133,243,
26,30,194,247,138,182,173,127,147,196,183,227,130,160,67,240,
251,207,239,179,208,241,173,134,107,77,234,61,137,189,51,176,
238,171,147,173,101,205,57,132,109,59,230,209,37,27,243,86,
34,230,214,49,193,136,245,185,230,223,194,175,224,39,69,219,
214,239,186,141,107,201,62,78,215,117,4,254,95,185,90,9,
125,211,26,254,243,17,93,158,143,127,223,125,181,160,173,207,
190,109,228,154,32,233,19,152,147,228,116,139,232,214,94,185,
71,63,133,95,195,166,189,114,252,109,106,16,214,148,19,188,
231,5,237,41,114,151,224,192,191,131,73,180,213,225,195,124,
78,246,104,121,166,158,175,113,47,193,28,142,96,76,234,92,
199,112,44,253,99,146,235,141,197,142,245,175,8,168,249,59,
190,15,192,181,4,152,159,201,83,254,188,134,199,137,11,236,
71,21,52,71,229,101,34,14,64,253,223,146,142,129,124,54,
28,87,241,76,190,84,180,118,176,143,189,141,120,30,62,111,
18,103,115,180,77,98,137,241,153,205,207,171,251,228,252,244,
217,215,18,247,220,223,236,216,251,247,177,87,240,15,120,2,
142,241,41,244,80,139,57,57,247,109,218,190,71,252,255,160,
14,226,238,152,95,139,251,244,85,184,11,238,211,207,224,47,
224,125,24,171,75,200,237,239,119,216,49,142,115,114,254,178,
180,51,137,125,214,50,86,57,132,5,248,91,33,62,123,97,
171,179,116,52,98,61,250,167,228,90,47,226,167,230,62,32,
225,20,124,94,149,24,39,230,185,105,206,198,187,62,81,166,
228,58,231,175,21,242,252,183,173,107,189,79,193,154,222,63,
241,255,201,156,175,58,248,4,187,37,75,156,43,120,15,102,
21,250,236,51,198,51,113,236,61,136,179,213,167,92,195,188,
224,30,134,173,182,47,75,71,35,159,239,148,92,243,78,224,
28,148,41,185,198,155,247,34,185,174,35,214,236,56,174,209,
179,106,97,95,150,88,171,249,202,148,92,199,247,92,23,38,
34,83,114,141,55,239,69,115,205,183,222,10,222,255,220,13,
191,68,75,180,237,171,215,251,160,248,226,57,242,30,127,4,
254,86,253,21,254,9,222,197,75,176,47,203,156,70,222,231,
88,187,113,25,215,100,95,150,142,70,236,181,254,41,185,245,
62,79,201,173,215,59,37,215,121,186,22,81,166,230,222,100,
221,252,249,99,212,10,30,194,65,65,91,159,125,181,188,139,
227,41,88,219,179,248,83,225,119,104,241,204,236,187,15,28,
249,173,204,177,242,25,229,115,201,182,185,174,39,75,71,35,
159,81,142,207,118,43,183,62,163,28,159,237,86,174,115,208,
47,74,142,207,118,43,183,35,190,158,115,196,57,167,26,92,
107,178,143,199,61,91,194,121,194,182,126,49,166,37,39,56,
205,89,129,117,253,13,86,219,14,222,198,174,101,142,195,113,
157,159,98,173,15,161,135,107,112,221,151,240,24,106,137,245,
154,175,76,201,181,222,33,44,76,68,166,228,62,32,254,20,
226,183,99,74,174,181,172,249,34,117,157,115,126,7,79,173,
107,237,144,31,98,248,125,245,8,92,139,223,131,63,135,214,
25,225,126,78,172,187,130,89,194,182,126,207,36,222,191,152,
159,189,99,243,249,30,226,115,237,158,171,239,126,199,136,92,
204,231,164,62,223,41,185,245,249,78,201,117,18,206,81,148,
41,185,115,226,243,122,247,104,59,151,26,247,188,150,122,189,
83,114,235,245,78,201,117,30,121,189,219,230,126,133,60,239,
141,223,238,162,253,13,88,194,21,120,198,226,216,135,80,75,
253,28,221,35,224,13,136,188,172,235,220,122,159,29,223,58,
57,103,168,110,189,207,83,114,235,125,158,146,91,175,119,74,
174,235,119,61,162,76,205,141,251,119,147,189,254,239,10,117,
127,196,101,253,46,141,167,224,28,252,54,250,24,252,94,178,
93,191,127,113,173,61,251,249,108,194,190,34,238,194,224,74,
234,51,138,248,172,135,114,235,51,202,57,97,15,229,58,13,
215,35,74,196,103,61,148,59,101,206,61,99,31,195,17,100,
241,57,242,247,67,150,112,94,161,47,250,141,13,217,118,206,
61,9,117,221,127,3,163,76,38,46,24,60,0,0,};
